@@ -1,8 +1,8 @@
 #ifndef _ISL_INCLUDE_ISL_STDINT_H
 #define _ISL_INCLUDE_ISL_STDINT_H 1
 #ifndef _GENERATED_STDINT_H
-#define _GENERATED_STDINT_H "isl 0.15"
-/* generated using gnu compiler gcc.exe (Rev4, Built by MSYS2 project) 5.2.0 */
+#define _GENERATED_STDINT_H "isl 0.17.1"
+/* generated using gnu compiler gcc.exe (Rev1, Built by MSYS2 project) 6.1.0 */
 #define _STDINT_HAVE_STDINT_H 1
 #include <stdint.h>
 #endif
